Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/derivepassphrase/__init__.py | 134 | 0 | 0 | 51 | 0 | 100.000%
src/derivepassphrase/cli.py | 343 | 0 | 11 | 177 | 0 | 100.000%
src/derivepassphrase/types.py | 54 | 0 | 0 | 34 | 4 | 95.455%
src/sequin/__init__.py | 97 | 0 | 0 | 44 | 0 | 100.000%
src/ssh_agent_client/__init__.py | 111 | 0 | 2 | 32 | 0 | 100.000%
src/ssh_agent_client/types.py | 13 | 0 | 0 | 0 | 0 | 100.000%
tests/__init__.py | 58 | 0 | 8 | 10 | 0 | 100.000%
tests/test_derivepassphrase.py | 93 | 0 | 0 | 24 | 0 | 100.000%
tests/test_derivepassphrase_cli.py | 356 | 0 | 8 | 94 | 1 | 99.778%
tests/test_derivepassphrase_typing.py | 8 | 0 | 0 | 0 | 0 | 100.000%
tests/test_sequin.py | 56 | 0 | 0 | 14 | 0 | 100.000%
tests/test_ssh_agent_client.py | 166 | 0 | 10 | 60 | 0 | 100.000%
Total | 1489 | 0 | 39 | 540 | 5 | 99.754%

No items found using the specified filter.